"""
Extract data easily from your VMWare clusters.

For more information, see https://github.com/ipamo/vmware-reporter.

Copyright (C) 2024, Sébastien Hocquet - MIT license.
"""
from __future__ import annotations

from .client import VCenterClient
from .datastore import (DatastoreElement, DatastoreStat, delete_from_datastore, download_from_datastore, export_datastore_elements, export_datastore_stats,
                        request_datastore_resource, get_datastore_stats, iterate_datastore_elements, upload_to_datastore)
from .dump import export_obj_dump
from .inspect import (dictify_value, dump_obj, get_obj_attr, get_obj_name,
                      get_obj_name_or_ref, get_obj_path, get_obj_ref,
                      identify_obj)
from .inventory import InventoryNode, build_inventory, export_inventory
from .utils import __prog__

try:
    # Version generated by setuptools_scm during build
    from ._version import __version__, __version_tuple__
except ImportError:
    __version__ = None
    __version_tuple__ = None

__all__ = (
    # client
    'VCenterClient',
    # datastore
    'DatastoreElement', 'DatastoreStat', 'delete_from_datastore', 'download_from_datastore', 'export_datastore_elements', 'export_datastore_stats',
    'request_datastore_resource', 'get_datastore_stats', 'iterate_datastore_elements', 'upload_to_datastore',
    # dump
    'export_obj_dump',
    # inspect
    'dictify_value', 'dump_obj', 'get_obj_attr', 'get_obj_name',
    'get_obj_name_or_ref', 'get_obj_path', 'get_obj_ref',
    'identify_obj',
    # inventory
    'InventoryNode', 'build_inventory', 'export_inventory',
    # utils
    '__prog__', '__version__', '__version_tuple__'
)
